@@ -1,6 +1,8 @@
 package Dist::Zilla::Plugin::Git::Describe;
+# git description: 0.004-1-g78d6184
+
 # ABSTRACT: add the results of `git describe` (roughly) to your main module
-$Dist::Zilla::Plugin::Git::Describe::VERSION = '0.004';
+$Dist::Zilla::Plugin::Git::Describe::VERSION = '0.005';
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -46,6 +48,7 @@ sub munge_files {
 
   my $file = $self->zilla->main_module;
 
+  require PPI::Document;
   my $document = $self->ppi_document_for_file($file);
 
   return unless my $package_stmts = $document->find('PPI::Statement::Package');
@@ -103,7 +106,7 @@ Dist::Zilla::Plugin::Git::Describe - add the results of `git describe` (roughly)
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -135,6 +138,12 @@ L<PodVersion|Dist::Zilla::Plugin::PkgVersion>
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Karen Etheridge
+
+Karen Etheridge <ether@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Ricardo Signes.
